@@ -6,7 +6,7 @@ function (formula, data, ...)
     y<-model.response(mf)
     LR<-matrix(SurvtoLR(y),ncol=2)
     x<-model.matrix(attr(mf,'terms'),data=mf)  # get design matrix
-    xcov<-x[,-1]  # delete intercept column
+    xcov<-x[,-1,drop=F]  # delete intercept column
     est<-ICBayes.default(L=LR[,1],R=LR[,2],xcov=xcov,...)
     #est<-do.call('ICBayes',c(list(L=LR[,1],R=LR[,2],xcov=xcov),list(...)))
     est$call <- match.call()
